==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/actions/ShowDeviceViewAction.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.actions;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.AbstractAction;
import javax.swing.KeyStroke;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.kernel.ControllerProxy;
import net.sourceforge.atunes.kernel.controllers.navigation.NavigationControllerViews;
import net.sourceforge.atunes.utils.LanguageTool;

/**
 * This action shows device view in navigator
 * 
 * @author fleax
 * 
 */
public class ShowDeviceViewAction extends AbstractAction {

	/**
	 * 
	 */
	private static final long serialVersionUID = -2720418911644318806L;

	ShowDeviceViewAction() {
		super(LanguageTool.getString("DEVICE_VIEW"), ImageLoader.DEVICE);
		putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke(KeyEvent.VK_3, ActionEvent.ALT_MASK));

	}

	@Override
	public void actionPerformed(ActionEvent e) {
		ControllerProxy.getInstance().getNavigationController().setNavigationView(NavigationControllerViews.DEVICE_VIEW);
	}

}

==> aTunes_1.11.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/actions/ShowDeviceViewAction.java <==
/*
 * aTunes 1.11.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.actions;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.AbstractAction;
import javax.swing.KeyStroke;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.kernel.ControllerProxy;
import net.sourceforge.atunes.kernel.modules.navigator.DeviceNavigationView;
import net.sourceforge.atunes.utils.LanguageTool;

/**
 * This action shows device view in navigator
 * 
 * @author fleax
 * 
 */
public class ShowDeviceViewAction extends AbstractAction {

	/**
	 * 
	 */
	private static final long serialVersionUID = -2720418911644318806L;

	ShowDeviceViewAction() {
		super(LanguageTool.getString("DEVICE_VIEW"), ImageLoader.DEVICE);
		putValue(ACCELERATOR_KEY, KeyStroke.getKeyStroke(KeyEvent.VK_3, ActionEvent.ALT_MASK));

	}

	@Override
	public void actionPerformed(ActionEvent e) {
		ControllerProxy.getInstance().getNavigationController().setNavigationView(DeviceNavigationView.class.getName());
	}

}
